@@ -1,7 +1,8 @@
 # pragma once
 // // [[Rcpp::depends(RcppParallel)]]
 // # include <Rcpp.h>
-# include <RcppParallel.h>
+#include <atomic>
+// #include <RcppParallel.h>
 // using namespace Rcpp;
 // using namespace RcppParallel;
 
@@ -10,7 +11,8 @@ struct dynamicTasking
 {
   std::size_t NofCore;
   std::size_t NofAtom;
-  tbb::atomic<std::size_t> counter;
+  // tbb::atomic<std::size_t> counter;
+  std::atomic<std::size_t> counter;
 
 
   void reset(std::size_t &NofCPU, std::size_t NofTask)
@@ -30,14 +32,16 @@ struct dynamicTasking
 
   bool nextTaskID(std::size_t &taskID)
   {
-    taskID = counter.fetch_and_increment();
+    // taskID = counter.fetch_and_increment();
+	taskID = counter.fetch_add(1);
     return taskID < NofAtom;
   }
 
 
   bool nextTaskID(std::size_t &taskID, std::size_t increment)
   {
-    taskID = counter.fetch_and_add(increment);
+    // taskID = counter.fetch_and_add(increment);
+	taskID = counter.fetch_add(increment);
     return taskID < NofAtom;
   }
 };
